<?php
/**
 * Plugin Name: Web Aika News - Custom Post Type
 * Plugin URI: https://www.webaika.com/plugins
 * Description: Standard plugin that's used to create custom post types.
 * Version: 1.0
 * Author: Peter Kornev
 * Author URI: https://www.webaika.com.com
 */

/* IMPORTANT 

PLUGIN REQUIRES:
1) Advanced custom Fields Pro to be installed bfore this plugin.


*/

// Load archive template for custom post type news
function get_custom_post_type_template( $archive_template ) {
     global $post;
     if ( is_post_type_archive ( 'news' ) ) {
          $archive_template = dirname( __FILE__ ) . '/archive-news.php';
     }
     return $archive_template;
}
add_filter( 'archive_template', 'get_custom_post_type_template' ) ;

/* Filter the single_template with our custom function*/
add_filter('single_template', 'my_custom_template');

// Load single template for custom post type news
function my_custom_template($single) {
    global $post;
    /* Checks for single template by post type */
    if ( $post->post_type == 'news' ) {
        if ( file_exists( dirname( __FILE__ ) . '/single-news.php' ) ) {
            return dirname( __FILE__ ) . '/single-news.php';
        }
    }
    return $single;
}

// ADD webaika-news css
add_action('wp_enqueue_scripts', 'callback_for_setting_up_scripts');
function callback_for_setting_up_scripts() {
    wp_register_style( 'namespace', plugins_url('/css/style.css?t='.time(),__FILE__ ));
    wp_enqueue_style( 'namespace' );
}
// Custom post type registration.

function aik_add_news() {
    $args = array(
        'label' => __('News'),
        'singular_label' => __('News'),
        'public' => true,
        'show_ui' => true,
        'capability_type' => 'post',
        'hierarchical' => false,
        'rewrite' => true,
        'supports' => array('title', 'author', 'thumbnail'),
        'menu_position' => 10,
        'has_archive' => true,
		'publicly_queryable' => true
    );
    register_post_type( 'news' , $args );
}
add_action('init', 'aik_add_news');

// Post pagination
if ( ! function_exists( 'wpbeginner_numeric_posts_nav' ) ){
	function wpbeginner_numeric_posts_nav() {
		if( is_singular() )
			return;
		global $wp_query;
		/** Stop execution if there's only 1 page */
		if( $wp_query->max_num_pages <= 1 )
			return;
		$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
		$max   = intval( $wp_query->max_num_pages );
		/** Add current page to the array */
		if ( $paged >= 1 )
			$links[] = $paged;
		/** Add the pages around the current page to the array */
		if ( $paged >= 3 ) {
			$links[] = $paged - 1;
			$links[] = $paged - 2;
		}
		if ( ( $paged + 2 ) <= $max ) {
			$links[] = $paged + 2;
			$links[] = $paged + 1;
		}
		echo '<div class="navigation"><ul style="padding-left: 0;">' . "\n";
		/** Previous Post Link */
		if ( get_previous_posts_link() )
			printf( '<li>%s</li>' . "\n", get_previous_posts_link() );
		/** Link to first page, plus ellipses if necessary */
		if ( ! in_array( 1, $links ) ) {
			$class = 1 == $paged ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );
			if ( ! in_array( 2, $links ) )
				echo '<li>…</li>';
		}
		/** Link to current page, plus 2 pages in either direction if necessary */
		sort( $links );
		foreach ( (array) $links as $link ) {
			$class = $paged == $link ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
		}
		/** Link to last page, plus ellipses if necessary */
		if ( ! in_array( $max, $links ) ) {
			if ( ! in_array( $max - 1, $links ) )
				echo '<li>…</li>' . "\n";
			$class = $paged == $max ? ' class="active"' : '';
			printf( '<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
		}
		/** Next Post Link */
		if ( get_next_posts_link() )
			printf( '<li>%s</li>' . "\n", get_next_posts_link() );
		echo '</ul></div>' . "\n";
	}
}



if( function_exists('acf_add_local_field_group') ):

acf_add_local_field_group(array(
	'key' => 'group_5c83e4ffdb928',
	'title' => 'News',
	'fields' => array(
		array(
			'key' => 'field_5cfa7fb55d257',
			'label' => 'Image',
			'name' => 'image',
			'type' => 'image',
			'instructions' => '250px X 250px',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'return_format' => 'array',
			'preview_size' => 'full',
			'library' => 'all',
			'min_width' => '',
			'min_height' => '',
			'min_size' => '',
			'max_width' => '',
			'max_height' => '',
			'max_size' => '',
			'mime_types' => '',
		),
		array(
			'key' => 'field_5cfa86df54100',
			'label' => 'Excerpt',
			'name' => 'excerpt',
			'type' => 'textarea',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'default_value' => '',
			'placeholder' => '',
			'maxlength' => '',
			'rows' => '',
			'new_lines' => '',
		),
		array(
			'key' => 'field_5c83e4ffe4a0d',
			'label' => 'Link Type',
			'name' => 'link_type',
			'type' => 'radio',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => 0,
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'choices' => array(
				'none' => 'No Link',
				'newpost' => 'New Post',
				'internal' => 'Internal Page',
				'external' => 'External Website',
			),
			'allow_null' => 0,
			'other_choice' => 0,
			'default_value' => 'none : No Link',
			'layout' => 'vertical',
			'return_format' => 'value',
			'save_other_choice' => 0,
		),
		array(
			'key' => 'field_5c83e4ffe4a85',
			'label' => 'New Post',
			'name' => 'new_post',
			'type' => 'wysiwyg',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
				array(
					array(
						'field' => 'field_5c83e4ffe4a0d',
						'operator' => '==',
						'value' => 'newpost',
					),
				),
			),
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'default_value' => '',
			'tabs' => 'all',
			'toolbar' => 'full',
			'media_upload' => 1,
			'delay' => 0,
		),
		array(
			'key' => 'field_5c83e4ffe4aee',
			'label' => 'Internal Page',
			'name' => 'internal_page_content',
			'type' => 'page_link',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
				array(
					array(
						'field' => 'field_5c83e4ffe4a0d',
						'operator' => '==',
						'value' => 'internal',
					),
				),
			),
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'post_type' => array(
				0 => 'page',
				1 => 'post',
				2 => 'event',
				3 => 'news',
				4 => 'press',
				5 => 'story',
				6 => 'webinar',
			),
			'taxonomy' => '',
			'allow_null' => 0,
			'allow_archives' => 1,
			'multiple' => 0,
		),
		array(
			'key' => 'field_5c83e4ffe4b66',
			'label' => 'External Link',
			'name' => 'external_link',
			'type' => 'url',
			'instructions' => '',
			'required' => 0,
			'conditional_logic' => array(
				array(
					array(
						'field' => 'field_5c83e4ffe4a0d',
						'operator' => '==',
						'value' => 'external',
					),
				),
			),
			'wrapper' => array(
				'width' => '',
				'class' => '',
				'id' => '',
			),
			'default_value' => '',
			'placeholder' => '',
		),
	),
	'location' => array(
		array(
			array(
				'param' => 'post_type',
				'operator' => '==',
				'value' => 'news',
			),
		),
	),
	'menu_order' => 0,
	'position' => 'normal',
	'style' => 'default',
	'label_placement' => 'top',
	'instruction_placement' => 'label',
	'hide_on_screen' => '',
	'active' => true,
	'description' => '',
));

endif;

// Move Yoast to bottom of the page
if ( ! function_exists( 'move_yoast_below_acf' ) ){
	function move_yoast_below_acf() {
		return 'low';
	}
	add_filter( 'wpseo_metabox_prio', 'move_yoast_below_acf');
}
